#!/bin/sh
########################################################################
## detect-system.sh (V0.1):
## Common code to detect different Linux distributions.
## Intended to be used with "Meta Spec Files", i.e. scripts that are 
## supposed to produce a distro specific RPM spec file for a given
## distro.
##
## To use, simply add
##
## source `dirname $0`/detect-system.sh
##
## to your Meta Spec File.
##
##
## Current Maintainer:	               Thomas Ribbrock <emgaron@gmx.net>
## Original Author:                    Thomas Ribbrock <emgaron@gmx.net>
## Based on an idea from:              Jim Knoble <jmknoble@pobox.com>
########################################################################


########################################################################
## Figuring out what kind of system it is that we're running on
##
HOST_ARCH="`uname -m | sed -e 's%[-/]%_%g'`"
HOST_OS="`uname -s | sed -e 's%[-/]%%g'`"
HOST_OS_VERSION="`uname -r | sed -e 's%[-/]%\.%g'`"
HOST_OS_VARIANT=""
HOST_OS_SUB_VERSION=""
case ${HOST_OS} in
    Linux)
        if [ -f /etc/redhat-release ]; then
            HOST_OS_VARIANT="RedHat"
	    HOST_OS_SUB_VERSION="`awk '{ print $2 }' </etc/redhat-release`"
	    if [ $HOST_OS_SUB_VERSION = "Hat" ]; then
	        HOST_OS_SUB_VERSION="`awk '{ print $5 }' </etc/redhat-release`"
	    fi 
	elif [ -f /etc/turbolinux-release ]; then
            HOST_OS_VARIANT="TurboLinux"
	    HOST_OS_SUB_VERSION="`awk '{ print $2 }' </etc/turbolinux-release`"
        elif [ -f /etc/rc.config ]; then
	    HOST_OS_VARIANT="SuSE"
	    HOST_OS_SUB_VERSION="unknown"
        else
            ## How do we test for Caldera or Mandrake?
	    HOST_OS_VARIANT="unknown"
	    HOST_OS_SUB_VERSION="unknown"
	fi
        ;;
esac
HOST_PLATFORM="${HOST_ARCH}-${HOST_OS}-${HOST_OS_VERSION}"
if [ -n "${HOST_OS_VARIANT}" ]; then
    HOST_PLATFORM="${HOST_PLATFORM}-${HOST_OS_VARIANT}-${HOST_OS_SUB_VERSION}"
fi

export HOST_ARCH HOST_OS HOST_OS_VERSION HOST_OS_VARIANT HOST_OS_SUB_VERSION
export HOST_PLATFORM

case "${HOST_ARCH}" in
    i*86)
        PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DX86=1"
        ;;
    sparc)
        PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DSPARC=1"
        ;;
    alpha)
        PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DALPHA=1"
        ;;
esac

case "${HOST_PLATFORM}" in
    *Linux*RedHat-5.9|*Linux*RedHat-6*)
        PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DLINUX=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DVARIANT=.rhl6"
        PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DREDHAT=1"
        PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DREDHAT6=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DGOT_WMCONFIG=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DMIME_TYPE_FIX=1"
        ;;
    *Linux*RedHat-5*)
        PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DLINUX=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DVARIANT=.rhl5"
        PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DREDHAT=1"
        PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DREDHAT5=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DGOT_WMCONFIG=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DMIME_TYPE_FIX=1"
        ;;
    *Linux*RedHat-4*)
        PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DLINUX=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DVARIANT=.rhl4"
        PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DREDHAT=1"
        PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DREDHAT4=1"
        ;;
    *Linux*TurboLinux*)
        PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DLINUX=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DVARIANT=.tl"
        PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DTURBOLINUX=1"
        ;;
    *Linux*SuSE*)
        PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DLINUX=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DVARIANT=.suse6_2"
        PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DSUSE=1"
	PREPROCESSOR_FLAGS="${PREPROCESSOR_FLAGS} -DMIME_TYPE_FIX=1"
        ;;
    *)
        echo "Hmm ... this appears to be '${HOST_PLATFORM}'"
	echo "I don't know much about that platform."
	echo "Please add support for your platform in an orderly fashion"
	echo "and contact the maintainer of this meta-specfile"
	echo "to merge the changes into it."
        ;;
esac

export PREPROCESSOR_FLAGS

########################################################################
## Change Log
##

## 15/10/1999:
## Initial version
##
